==> zzyj-laborservice-impl-3.0.0-20250402.072543-82-sources.jar: com/ejianc/business/oa/bean/SealEntity.java <==
package com.ejianc.business.oa.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 合同用印申请表
 * 
 * @author generator
 * 
 */
 @TableName("zzyj_laborservice_seal")
public class SealEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="apply_user_id")
    private Long applyUserId; // 申请人ID
    @TableField(value="apply_user_name")
    private String applyUserName; // 申请人姓名
    @TableField(value="apply_time")
    private Date applyTime; // 申请时间
    @TableField(value="contract_mny")
    private BigDecimal contractMny; // 合同金额(万元)
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="first_party")
    private String firstParty; // 甲方名称
    @TableField(value="first_party_state")
    private String firstPartyState; // 甲方资金状况
    @TableField(value="memo")
    private String memo; // 工程概况
    @TableField(value="engineering_type")
    private String engineeringType; // 工程类型
    @TableField(value="engineering_progress")
    private String engineeringProgress; // 工程进度
    @TableField(value="contract_type")
    private String contractType; // 合同类别
    @TableField(value="contract_sign_date")
    private Date contractSignDate; // 合同签订日期
    @TableField(value="invoice_type")
    private String invoiceType; // 开票类别
    @TableField(value="tax")
    private BigDecimal tax; // 税率
    @TableField(value="labor_leader")
    private String laborLeader; // 劳务队长
    @TableField(value="labor_leader_phone")
    private String laborLeaderPhone; // 劳务队长联系方式
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="seal_type")
    private String sealType; // 内部|外部用印


    public String getSealType() {
        return sealType;
    }

    public void setSealType(String sealType) {
        this.sealType = sealType;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getApplyUserId() {
        return applyUserId;
    }

    public void setApplyUserId(Long applyUserId) {
        this.applyUserId = applyUserId;
    }
    public String getApplyUserName() {
        return applyUserName;
    }

    public void setApplyUserName(String applyUserName) {
        this.applyUserName = applyUserName;
    }
    public Date getApplyTime() {
        return applyTime;
    }

    public void setApplyTime(Date applyTime) {
        this.applyTime = applyTime;
    }
    public BigDecimal getContractMny() {
        return contractMny;
    }

    public void setContractMny(BigDecimal contractMny) {
        this.contractMny = contractMny;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getFirstParty() {
        return firstParty;
    }

    public void setFirstParty(String firstParty) {
        this.firstParty = firstParty;
    }
    public String getFirstPartyState() {
        return firstPartyState;
    }

    public void setFirstPartyState(String firstPartyState) {
        this.firstPartyState = firstPartyState;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getEngineeringType() {
        return engineeringType;
    }

    public void setEngineeringType(String engineeringType) {
        this.engineeringType = engineeringType;
    }
    public String getEngineeringProgress() {
        return engineeringProgress;
    }

    public void setEngineeringProgress(String engineeringProgress) {
        this.engineeringProgress = engineeringProgress;
    }
    public String getContractType() {
        return contractType;
    }

    public void setContractType(String contractType) {
        this.contractType = contractType;
    }
    public Date getContractSignDate() {
        return contractSignDate;
    }

    public void setContractSignDate(Date contractSignDate) {
        this.contractSignDate = contractSignDate;
    }
    public String getInvoiceType() {
        return invoiceType;
    }

    public void setInvoiceType(String invoiceType) {
        this.invoiceType = invoiceType;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getLaborLeader() {
        return laborLeader;
    }

    public void setLaborLeader(String laborLeader) {
        this.laborLeader = laborLeader;
    }
    public String getLaborLeaderPhone() {
        return laborLeaderPhone;
    }

    public void setLaborLeaderPhone(String laborLeaderPhone) {
        this.laborLeaderPhone = laborLeaderPhone;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}

==> zzyj-laborservice-impl-3.0.0-20251016.023314-93-sources.jar: com/ejianc/business/oa/bean/SealEntity.java <==
package com.ejianc.business.oa.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 合同用印申请表
 * 
 * @author generator
 * 
 */
 @TableName("zzyj_laborservice_seal")
public class SealEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="apply_user_id")
    private Long applyUserId; // 申请人ID
    @TableField(value="apply_user_name")
    private String applyUserName; // 申请人姓名
    @TableField(value="apply_time")
    private Date applyTime; // 申请时间
    @TableField(value="contract_mny")
    private BigDecimal contractMny; // 合同金额(万元)
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="first_party")
    private String firstParty; // 甲方名称
    @TableField(value="first_party_state")
    private String firstPartyState; // 甲方资金状况
    @TableField(value="memo")
    private String memo; // 工程概况
    @TableField(value="engineering_type")
    private String engineeringType; // 工程类型
    @TableField(value="engineering_progress")
    private String engineeringProgress; // 工程进度
    @TableField(value="contract_type")
    private String contractType; // 合同类别
    @TableField(value="contract_sign_date")
    private Date contractSignDate; // 合同签订日期
    @TableField(value="invoice_type")
    private String invoiceType; // 开票类别
    @TableField(value="tax")
    private BigDecimal tax; // 税率
    @TableField(value="labor_leader")
    private String laborLeader; // 劳务队长
    @TableField(value="labor_leader_phone")
    private String laborLeaderPhone; // 劳务队长联系方式
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="seal_type")
    private String sealType; // 内部|外部用印

    @TableField(value="manager_rate")
    private BigDecimal managerRate; //

    public BigDecimal getManagerRate() {
        return managerRate;
    }

    public void setManagerRate(BigDecimal managerRate) {
        this.managerRate = managerRate;
    }

    public String getSealType() {
        return sealType;
    }

    public void setSealType(String sealType) {
        this.sealType = sealType;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getApplyUserId() {
        return applyUserId;
    }

    public void setApplyUserId(Long applyUserId) {
        this.applyUserId = applyUserId;
    }
    public String getApplyUserName() {
        return applyUserName;
    }

    public void setApplyUserName(String applyUserName) {
        this.applyUserName = applyUserName;
    }
    public Date getApplyTime() {
        return applyTime;
    }

    public void setApplyTime(Date applyTime) {
        this.applyTime = applyTime;
    }
    public BigDecimal getContractMny() {
        return contractMny;
    }

    public void setContractMny(BigDecimal contractMny) {
        this.contractMny = contractMny;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getFirstParty() {
        return firstParty;
    }

    public void setFirstParty(String firstParty) {
        this.firstParty = firstParty;
    }
    public String getFirstPartyState() {
        return firstPartyState;
    }

    public void setFirstPartyState(String firstPartyState) {
        this.firstPartyState = firstPartyState;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getEngineeringType() {
        return engineeringType;
    }

    public void setEngineeringType(String engineeringType) {
        this.engineeringType = engineeringType;
    }
    public String getEngineeringProgress() {
        return engineeringProgress;
    }

    public void setEngineeringProgress(String engineeringProgress) {
        this.engineeringProgress = engineeringProgress;
    }
    public String getContractType() {
        return contractType;
    }

    public void setContractType(String contractType) {
        this.contractType = contractType;
    }
    public Date getContractSignDate() {
        return contractSignDate;
    }

    public void setContractSignDate(Date contractSignDate) {
        this.contractSignDate = contractSignDate;
    }
    public String getInvoiceType() {
        return invoiceType;
    }

    public void setInvoiceType(String invoiceType) {
        this.invoiceType = invoiceType;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getLaborLeader() {
        return laborLeader;
    }

    public void setLaborLeader(String laborLeader) {
        this.laborLeader = laborLeader;
    }
    public String getLaborLeaderPhone() {
        return laborLeaderPhone;
    }

    public void setLaborLeaderPhone(String laborLeaderPhone) {
        this.laborLeaderPhone = laborLeaderPhone;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}
